@@ -2,12 +2,8 @@ import logging
 from pathlib import Path
 from typing import List, Callable
 
-from pvoutput_publisher.constants import ADD_BATCH_STATUS_SERVICE_NAME, ADD_BATCH_STATUS_URL, \
-    ADD_STATUS_SERVICE_NAME, ADD_STATUS_URL
-from pvoutput_publisher.publisher import publish_data
-from pvoutput_publisher.services.common.common import SystemDetails
-from pvoutput_publisher.services.status.add_batch_status_service import AddBatchStatus
-from pvoutput_publisher.services.status.add_status_service import AddStatus
+from pvoutput_publisher.services.add_batch_status import AddBatchStatus, publish_add_batch_status
+from pvoutput_publisher.services.add_status import AddStatus, publish_add_status
 
 from pysunspec_to_pvoutput.config import PvOutputOptions, Config
 from pysunspec_to_pvoutput.file_utils.file_cache import FileProcessCache, move_to_completed
@@ -45,7 +41,9 @@ def convert_to_batch(reading_files: List[Path],
 
 def publish(add_status_creator, config: Config):
     publish_config = config.pvoutput_publish_options
-    system_details = SystemDetails(api_key=publish_config.secret_api_key, system_id=str(publish_config.system_id))
+    api_key = publish_config.secret_api_key
+    system_id = str(publish_config.system_id)
+    is_donation_mode = publish_config.is_donation_mode
     cache = FileProcessCache(determine_cache_path(config))
     reading_files = cache.load()
 
@@ -55,16 +53,16 @@ def publish(add_status_creator, config: Config):
         for f in readings_batch:
             logger.info(f"Batch File {f}")
         statuses = convert_to_batch(readings_batch, publish_config, add_status_creator)
-        response = publish_data(ADD_BATCH_STATUS_SERVICE_NAME, statuses, system_details, ADD_BATCH_STATUS_URL)
-        for status in response.statuses:
-            if status.status_added:
-                logger.info(f"Batch reading was added or modified {status.date} {status.time}")
+        response = publish_add_batch_status(system_id, api_key, statuses, is_donation_mode)
+        for reading in response.reading_responses:
+            print("response date {} time {} result {}".format(reading.reading_date, reading.reading_time,
+                                                              reading.status_added))
         move_to_completed(readings_batch, cache)
     elif cache.size() == 1:
         logger.info(f"Single reading found in cache directory {reading_files[0]}")
         reading_json = read_json_dict_from_file(reading_files[0])
         status = add_status_creator(reading_json, publish_config)
-        publish_data(ADD_STATUS_SERVICE_NAME, status, system_details, ADD_STATUS_URL)
+        publish_add_status(system_id, api_key, status, is_donation_mode)
         logger.info("Single reading was published")
         move_to_completed([reading_files[0]], cache)
     else:
